==> Task-BeLike-SHLOMIF-0.0.1.tar.gz: Task-BeLike-SHLOMIF-0.0.1/lib/Task/BeLike/SHLOMIF.pm <==
package Task::BeLike::SHLOMIF;

use strict;
use warnings;

1;

__END__

=pod

=head1 NAME

Task::BeLike::SHLOMIF - Be like SHLOMIF / Shlomi Fish.

=head1 VERSION

version 0.0.1

=head1 TASK CONTENTS

=head2 Shlomi Fish's Favourite Dists

=head3 L<Dist::Zilla::PluginBundle::SHLOMIF>

=head3 L<Pod::Coverage::TrustPod>

=head3 L<Pod::Xhtml>

=head3 L<SQ>

=head3 L<Task::FreecellSolver::Testing>

=head3 L<Task::Sites::ShlomiFish>

=head3 L<Term::ReadLine::Gnu>

=head3 L<Term::ReadLine::Perl5>

=head3 L<Test::Pod>

=head1 AUTHOR

Shlomi Fish <shlomif@cpan.org>

=head1 COPYRIGHT AND LICENSE

This software is Copyright (c) 2018 by Shlomi Fish.

This is free software, licensed under:

  The MIT (X11) License

=for :stopwords cpan testmatrix url annocpan anno bugtracker rt cpants kwalitee diff irc mailto metadata placeholders metacpan

=head1 SUPPORT

=head2 Perldoc

You can find documentation for this module with the perldoc command.

  perldoc Task::BeLike::SHLOMIF

=head2 Websites

The following websites have more information about this module, and may be of help to you. As always,
in addition to those websites please use your favorite search engine to discover more resources.

=over 4

=item *

MetaCPAN

A modern, open-source CPAN search engine, useful to view POD in HTML format.

L<https://metacpan.org/release/Task-BeLike-SHLOMIF>

=item *

Search CPAN

The default CPAN search engine, useful to view POD in HTML format.

L<http://search.cpan.org/dist/Task-BeLike-SHLOMIF>

=item *

RT: CPAN's Bug Tracker

The RT ( Request Tracker ) website is the default bug/issue tracking system for CPAN.

L<https://rt.cpan.org/Public/Dist/Display.html?Name=Task-BeLike-SHLOMIF>

=item *

AnnoCPAN

The AnnoCPAN is a website that allows community annotations of Perl module documentation.

L<http://annocpan.org/dist/Task-BeLike-SHLOMIF>

=item *

CPAN Ratings

The CPAN Ratings is a website that allows community ratings and reviews of Perl modules.

L<http://cpanratings.perl.org/d/Task-BeLike-SHLOMIF>

=item *

CPANTS

The CPANTS is a website that analyzes the Kwalitee ( code metrics ) of a distribution.

L<http://cpants.cpanauthors.org/dist/Task-BeLike-SHLOMIF>

=item *

CPAN Testers

The CPAN Testers is a network of smoke testers who run automated tests on uploaded CPAN distributions.

L<http://www.cpantesters.org/distro/T/Task-BeLike-SHLOMIF>

=item *

CPAN Testers Matrix

The CPAN Testers Matrix is a website that provides a visual overview of the test results for a distribution on various Perls/platforms.

L<http://matrix.cpantesters.org/?dist=Task-BeLike-SHLOMIF>

=item *

CPAN Testers Dependencies

The CPAN Testers Dependencies is a website that shows a chart of the test results of all dependencies for a distribution.

L<http://deps.cpantesters.org/?module=Task::BeLike::SHLOMIF>

=back

=head2 Bugs / Feature Requests

Please report any bugs or feature requests by email to C<bug-task-belike-shlomif at rt.cpan.org>, or through
the web interface at L<https://rt.cpan.org/Public/Bug/Report.html?Queue=Task-BeLike-SHLOMIF>. You will be automatically notified of any
progress on the request by the system.

=head2 Source Code

The code is open to the world, and available for you to hack on. Please feel free to browse it and play
with it, or whatever. If you want to contribute patches, please send me a diff or prod me to pull
from your repository :)

L<https://github.com/shlomif/Task-BeLike-SHLOMIF>

  git clone https://github.com/shlomif/Task-BeLike-SHLOMIF.git

=cut

==> Task-BeLike-SHLOMIF-0.0.2.tar.gz: Task-BeLike-SHLOMIF-0.0.2/lib/Task/BeLike/SHLOMIF.pm <==
package Task::BeLike::SHLOMIF;
$Task::BeLike::SHLOMIF::VERSION = '0.0.2';
use strict;
use warnings;

1;

__END__

=pod

=head1 NAME

Task::BeLike::SHLOMIF - Be like SHLOMIF / Shlomi Fish.

=head1 VERSION

version 0.0.2

=head1 TASK CONTENTS

=head2 Shlomi Fish's Favourite Dists

=head3 L<Dist::Zilla::PluginBundle::SHLOMIF>

=head3 L<Pod::Coverage::TrustPod>

=head3 L<Pod::Xhtml>

=head3 L<SQ>

=head3 L<Task::FreecellSolver::Testing>

=head3 L<Task::Sites::ShlomiFish>

=head3 L<Term::ReadLine::Gnu>

=head3 L<Term::ReadLine::Perl5>

=head3 L<Test::Pod>

=head1 VERSION

version 0.0.2

=head1 AUTHOR

Shlomi Fish <shlomif@cpan.org>

=head1 COPYRIGHT AND LICENSE

This software is Copyright (c) 2018 by Shlomi Fish.

This is free software, licensed under:

  The MIT (X11) License

=head1 BUGS

Please report any bugs or feature requests on the bugtracker website
L<https://github.com/shlomif/task-belike-shlomif/issues>

When submitting a bug or request, please include a test-file or a
patch to an existing test-file that illustrates the bug or desired
feature.

=for :stopwords cpan testmatrix url annocpan anno bugtracker rt cpants kwalitee diff irc mailto metadata placeholders metacpan

=head1 SUPPORT

=head2 Perldoc

You can find documentation for this module with the perldoc command.

  perldoc Task::BeLike::SHLOMIF

=head2 Websites

The following websites have more information about this module, and may be of help to you. As always,
in addition to those websites please use your favorite search engine to discover more resources.

=over 4

=item *

MetaCPAN

A modern, open-source CPAN search engine, useful to view POD in HTML format.

L<https://metacpan.org/release/Task-BeLike-SHLOMIF>

=item *

Search CPAN

The default CPAN search engine, useful to view POD in HTML format.

L<http://search.cpan.org/dist/Task-BeLike-SHLOMIF>

=item *

RT: CPAN's Bug Tracker

The RT ( Request Tracker ) website is the default bug/issue tracking system for CPAN.

L<https://rt.cpan.org/Public/Dist/Display.html?Name=Task-BeLike-SHLOMIF>

=item *

AnnoCPAN

The AnnoCPAN is a website that allows community annotations of Perl module documentation.

L<http://annocpan.org/dist/Task-BeLike-SHLOMIF>

=item *

CPAN Ratings

The CPAN Ratings is a website that allows community ratings and reviews of Perl modules.

L<http://cpanratings.perl.org/d/Task-BeLike-SHLOMIF>

=item *

CPANTS

The CPANTS is a website that analyzes the Kwalitee ( code metrics ) of a distribution.

L<http://cpants.cpanauthors.org/dist/Task-BeLike-SHLOMIF>

=item *

CPAN Testers

The CPAN Testers is a network of smoke testers who run automated tests on uploaded CPAN distributions.

L<http://www.cpantesters.org/distro/T/Task-BeLike-SHLOMIF>

=item *

CPAN Testers Matrix

The CPAN Testers Matrix is a website that provides a visual overview of the test results for a distribution on various Perls/platforms.

L<http://matrix.cpantesters.org/?dist=Task-BeLike-SHLOMIF>

=item *

CPAN Testers Dependencies

The CPAN Testers Dependencies is a website that shows a chart of the test results of all dependencies for a distribution.

L<http://deps.cpantesters.org/?module=Task::BeLike::SHLOMIF>

=back

=head2 Bugs / Feature Requests

Please report any bugs or feature requests by email to C<bug-task-belike-shlomif at rt.cpan.org>, or through
the web interface at L<https://rt.cpan.org/Public/Bug/Report.html?Queue=Task-BeLike-SHLOMIF>. You will be automatically notified of any
progress on the request by the system.

=head2 Source Code

The code is open to the world, and available for you to hack on. Please feel free to browse it and play
with it, or whatever. If you want to contribute patches, please send me a diff or prod me to pull
from your repository :)

L<https://github.com/shlomif/Task-BeLike-SHLOMIF>

  git clone https://github.com/shlomif/Task-BeLike-SHLOMIF.git

=cut
